<?php
// Set up theme information
$theme_data = get_theme_data(TEMPLATEPATH.'/style.css');
define('THEME_NAME', $theme_data['Name']);
define('THEME_AUTHOR', $theme_data['Author']);
define('THEME_HOMEPAGE', $theme_data['URI']);
define('THEME_VERSION', trim($theme_data['Version']));
define('THEME_URL', get_template_directory_uri());
define('THEME_FILE', "Vovinam Light 2");


// Make theme available for translation
// Translations can be filed in the /languages/ directory
load_theme_textdomain(THEME_FILE, TEMPLATEPATH . '/languages');

$locale = get_locale();
$locale_file = TEMPLATEPATH . "/languages/$locale.php";
if ( is_readable( $locale_file ) )
	require_once( $locale_file );


// setting up the $vovinam_light_2_values variable
$vovinam_light_2_values = get_option(THEME_FILE);


function get_index($array, $index) {
  return isset($array[$index]) ? $array[$index] : null;
}


// CALL THEME OPTIONIS
function theme_option($var) {
	global $vovinam_light_2_values;
	$option = get_index($vovinam_light_2_values, $var);
	return $option;
}


function pbt_widgets_init() {
	// include the widgets
	include(TEMPLATEPATH.'/widgets/widget_login.php');
	include(TEMPLATEPATH.'/widgets/widget_feature.php'); 
	
	// Initiating the sidebars
	if (function_exists("register_sidebar")) {
		register_sidebar(array(
		'name' => 'Sidebar One',
			'before_widget' => '<div class="side-widget">',
			'after_widget' => '</div>',
			'before_title' => '<h2>',
			'after_title' => '</h2>'
		));
		
		if (theme_option('sidebar_width2')!=0) {
			register_sidebar(array(
				'name' => 'Sidebar Two',
				'before_widget' => '<div class="side-widget">',
				'after_widget' => '</div>',
				'before_title' => '<h2>',
				'after_title' => '</h2>'
			));
		}
	}
}
add_action( 'widgets_init', 'pbt_widgets_init' );



// Tags for keywords
function csv_tags() {
    $posttags = get_the_tags();
 	$csv_tags = '';
    if($posttags) {
		foreach((array)$posttags as $tag) {
			$csv_tags .= $tag->name . ',';
		}
	}
    echo '<meta name="keywords" content="'.$csv_tags.theme_option('keywords').'" />';
}


// Meta description
function metaDesc() {
	$content = apply_filters('the_content_rss', strip_tags(get_the_content()));
	$content = preg_replace('/\[.+\]/','', $content);
	$chars = array("", "\n", "\r", "chr(13)",  "\t", "\0", "\x0B");
	$content = htmlentities(str_replace($chars, " ", $content));
	if(empty($content)) {
		$content = htmlentities(theme_option('site_description'));
	}
	if (strlen($content) < 155) {
		echo $content;
	} else {
		$desc = substr($content,0,155);
		echo $desc."...";
	}
}


// Comments
function vlt_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
	<div id="comment-<?php comment_ID(); ?>">
        <div class="comment-avatar">
        	<?php echo get_avatar( $comment, 54 ); ?>
        </div>     
        <div class="comment-author">
        	<?php echo get_comment_author_link()." ";
        	printf('on %1$s at %2$s', get_comment_date(),get_comment_time()); 
			edit_comment_link('(Edit)','  ','');
			?>
        </div>
        <div class="comment-text">
	        <?php if ($comment->comment_approved == '0') { '<em>Deine Kommentare wartet auf Moderation.</em>'; } ?>
        	<?php comment_text() ?>
        </div>
        <?php if($args['max_depth']!=$depth && comments_open()) { ?>
        <div class="reply">
        	<?php comment_reply_link(array_merge($args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
        </div>
        <?php } ?>
	</div>
<?php        
}

// This theme uses wp_nav_menu()
if(function_exists('register_nav_menu')) {
	register_nav_menu('main', 'Main Navigation Menu');
}

add_theme_support( 'automatic-feed-links' );

function display_none() { }

/* ADDING NEW THUMBNAIL STUFF */
if(!function_exists('pbt_AddThumbColumn') && function_exists('add_theme_support')) {
 	add_theme_support('post-thumbnails');
 
	function pbt_AddThumbColumn($cols) {
		$cols['thumbnail'] = 'Thumbnail';
		return $cols;
	}
 
	function pbt_AddThumbValue($column_name, $post_id) {
		$width = (int) 35;
		$height = (int) 35;

		if ( 'thumbnail' == $column_name ) {
			// thumbnail of WP 2.9
			$thumbnail_id = get_post_meta( $post_id, '_thumbnail_id', true );
			// image from gallery
			if ($thumbnail_id) {
				$thumb = wp_get_attachment_image( $thumbnail_id, array($width, $height), true );
			}
			if(isset($thumb) && $thumb) {
				echo $thumb;
			} else {
				echo 'None';
			}
		}
	}
 
	// for posts
	add_filter( 'manage_posts_columns', 'pbt_AddThumbColumn' );
	add_action( 'manage_posts_custom_column', 'pbt_AddThumbValue', 10, 2 );
 
	// for pages
	add_filter( 'manage_pages_columns', 'pbt_AddThumbColumn' );
	add_action( 'manage_pages_custom_column', 'pbt_AddThumbValue', 10, 2 );
}

include(TEMPLATEPATH.'/content.php');
include(TEMPLATEPATH.'/widgets.php'); 

